import { Send, X } from 'lucide-react';
import { useEffect, useState } from 'react';
import { useSelector, useDispatch } from 'react-redux';
import { fetchCreatorDetail } from '../store/slices/creatorsSlice';
import { Button, Form } from 'react-bootstrap';

export default function ChatDetails({ onCloseChatDetails }) {
    const [search, setSearch] = useState('');
    const { selectedChat } = useSelector((state) => state.inbox);
    const { selectedCreator } = useSelector((state) => state.creators);
    const dispatch = useDispatch();

    const handleSubmit = (e) => {
        e.preventDefault();
        console.log('Form submitted');
    };

    useEffect(() => {
        dispatch(fetchCreatorDetail({ creatorId: selectedChat.id }));
    }, [dispatch, selectedChat]);

    return (
        <div className='chat-details'>
            <div className='chat-details-header'>
                <div className='chat-header-title'>
                    Chat Details
                    <div className='chat-detail-close-btn' onClick={onCloseChatDetails}>
                        <X />
                    </div>
                </div>
                <div className='chat-detail-header-creator'>
                    <div className='chat-detail-header-creator-avatar'>
                        <img src={selectedChat?.avatar} alt='avatar' />
                    </div>
                    <div className='chat-detail-header-creator-name'>{selectedChat?.name}</div>
                </div>
            </div>
            <div className='chat-detail-header-infos'>
                <div className='chat-detail-header-info-item'>
                    <div className='chat-detail-header-info-item-label'>Category</div>
                    <div className='chat-detail-header-info-item-value'>{selectedCreator?.category}</div>
                </div>
                <div className='chat-detail-header-info-item'>
                    <div className='chat-detail-header-info-item-label'>MCN</div>
                    <div className='chat-detail-header-info-item-value'>{selectedCreator?.mcn || '--'}</div>
                </div>
                <div className='chat-detail-header-info-item'>
                    <div className='chat-detail-header-info-item-label'>Pricing</div>
                    <div className='chat-detail-header-info-item-value'>{selectedCreator?.pricing || '--'}</div>
                </div>
                <div className='chat-detail-header-info-item'>
                    <div className='chat-detail-header-info-item-label'>Collab.</div>
                    <div className='chat-detail-header-info-item-value'>{selectedCreator?.collab || '--'}</div>
                </div>
            </div>
            <div className='chat-detail-summary'>
                <div className='chat-detail-summary-title'>Chat Summary</div>
                <Form.Control as='textarea' rows={6} className='chat-detail-summary-input' />
            </div>
            <div className='chat-detail-generate'>
                <div className='chat-detail-generate-title'>Chat Generate</div>
                <Form className='generate-form' onSubmit={handleSubmit}>
                    <Form.Control as='textarea' rows={4} className='generate-input' />
                    <Button className='rounded-pill submit-btn btn-sm' type='submit'>
                        <Send size={16} />
                    </Button>
                </Form>
            </div>
        </div>
    );
}
