import { Button, Form, Modal } from 'react-bootstrap';
import SearchBar from '../components/SearchBar';
import { Footprints, Plus } from 'lucide-react';
import React, { useEffect, useState } from 'react';
import { useDispatch } from 'react-redux';
import { addTemplateApi, editTemplateApi, fetchTemplates } from '../store/slices/inboxSlice';
import TemplateList from '../components/TemplateList';
import { CAMPAIGN_SERVICES } from '../lib/constant';

export default function InboxTemplate() {
    const [activeTab, setActiveTab] = useState('all');
    const [showAddTemplateModal, setShowAddTemplateModal] = useState(false);
    const [showEditTemplateModal, setShowEditTemplateModal] = useState(false);
    const [formData, setFormData] = useState({
        mission: '',
        platform: '',
        service: '',
        template: '',
    });
    const dispatch = useDispatch();

    useEffect(() => {
        dispatch(fetchTemplates(activeTab));
    }, [dispatch, activeTab]);

    return (
        <React.Fragment>
            <div className='function-bar'>
                <SearchBar />
                <Button onClick={() => setShowAddTemplateModal(true)}>
                    <Plus />
                    Add Template
                </Button>
            </div>
            <div className='breadcrumb'>
                <div className='breadcrumb-item'>Templates</div>
            </div>
            <div className='tab-switches'>
                <div
                    className={`tab-switch-item ${activeTab === 'all' ? 'active' : ''}`}
                    onClick={() => setActiveTab('all')}
                >
                    全部
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'initial' ? 'active' : ''}`}
                    onClick={() => setActiveTab('initial')}
                >
                    初步建联
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'bargain' ? 'active' : ''}`}
                    onClick={() => setActiveTab('bargain')}
                >
                    砍价邮件
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'script' ? 'active' : ''}`}
                    onClick={() => setActiveTab('script')}
                >
                    脚本邮件
                </div>
                <div
                    className={`tab-switch-item ${activeTab === 'cooperation' ? 'active' : ''}`}
                    onClick={() => setActiveTab('cooperation')}
                >
                    合作追踪
                </div>
            </div>
            <TemplateList
                activeTab={activeTab}
                openModal={() => setShowEditTemplateModal(true)}
                setFormData={setFormData}
            />
            <AddTemplateModal
                show={showAddTemplateModal}
                handleClose={() => setShowAddTemplateModal(false)}
                type='add'
                formData={formData}
                setFormData={setFormData}
            />
            <AddTemplateModal
                show={showEditTemplateModal}
                handleClose={() => setShowEditTemplateModal(false)}
                type='edit'
                formData={formData}
                setFormData={setFormData}
            />
        </React.Fragment>
    );
}

function AddTemplateModal({ show, formData, setFormData, handleClose, type = 'add' }) {
    const dispatch = useDispatch();

    const handleChange = (e) => {
        setFormData({
            ...formData,
            [e.target.name]: e.target.value,
        });
    };

    const handleSubmit = () => {
        console.log(formData);
				if(type === 'add') {
					dispatch(addTemplateApi(formData));
				} else {
					dispatch(editTemplateApi(formData));
				}
    };

    useEffect(() => {
    }, [formData]);

    return (
        <Modal show={show} onHide={handleClose}>
            <Modal.Header closeButton>
                <Modal.Title>{type === 'add' ? 'Add Template' : 'Edit Template'}</Modal.Title>
            </Modal.Header>
            <Modal.Body>
                <Form>
                    <Form.Group className='mb-3' controlId='formBasicEmail'>
                        <Form.Label>Mission</Form.Label>
                        <Form.Select
                            required
                            type='select'
                            placeholder='Select mission'
                            value={formData.mission}
                            name='mission'
                            onChange={handleChange}
                        >
                            <option value='' disabled>
                                Select mission
                            </option>
                            <option value='initial'>初步建联</option>
                            <option value='bargain'>砍价邮件</option>
                            <option value='script'>脚本邮件</option>
                            <option value='cooperation'>合作追踪</option>
                        </Form.Select>
                    </Form.Group>
                    <Form.Group className='mb-3' controlId='formBasicEmail'>
                        <Form.Label>Platform</Form.Label>
                        <Form.Select
                            required
                            type='select'
                            placeholder='Select platform'
                            value={formData.platform}
                            name='platform'
                            onChange={handleChange}
                        >
                            <option value='' disabled>
                                Select platform
                            </option>
                            <option value='TikTok'>TikTok</option>
                            <option value='Instagram'>Instagram</option>
                            <option value='Facebook'>Facebook</option>
                            <option value='YouTube'>Youtube</option>
                        </Form.Select>
                    </Form.Group>
                    <Form.Group className='mb-3' controlId='formBasicEmail'>
                        <Form.Label>合作模式</Form.Label>
                        <Form.Select
                            required
                            type='select'
                            value={formData.service}
                            name='service'
                            onChange={handleChange}
                        >
                            <option value='' disabled>
                                Select service
                            </option>
                            {CAMPAIGN_SERVICES.map((service) => (
                                <option value={service.value}>{service.name}</option>
                            ))}
                        </Form.Select>
                    </Form.Group>
                    <Form.Group className='mb-3' controlId='formBasicEmail'>
                        <Form.Label>Template</Form.Label>
                        <Form.Control
                            required
                            type='textarea'
                            as='textarea'
                            rows={10}
                            placeholder='Enter template'
                            value={formData.template}
                            name='template'
                            onChange={handleChange}
                        />
                    </Form.Group>
                </Form>
            </Modal.Body>
            <Modal.Footer>
                <Button variant='outline-primary' className='border-0' onClick={handleClose}>
                    Close
                </Button>
                <Button variant='primary' type='submit' onClick={handleSubmit}>
                    Create
                </Button>
            </Modal.Footer>
        </Modal>
    );
}
